@@ -4,6 +4,6 @@ from .connectivity import get_outer_faces, find_matching_blocks, get_face_inters
 from .read import read_plot3D
 from .write import write_plot3D
 from .differencing import find_edges, find_face_edges
-from .periodicity import periodicity
+from .periodicity import periodicity, periodicity_fast, create_rotation_matrix, rotated_periodicity
 from .point_match import point_match
 from .split_block import split_blocks, Direction
\ No newline at end of file
